@@ -1,6 +1,4 @@
-from enum import StrEnum
-
-class PollFields(StrEnum):
+class PollFields:
     """
     The Tweet will only return poll fields if the Tweet contains a poll and if
     you've also included the expansions=attachments.poll_ids query parameter in
